@@ -18,13 +18,19 @@ class CyclicQueuePool:
         return await self.pool.get()
 
     async def release(self, conn):
-        """Acquire connection."""
+        """Release connection."""
         return self.pool.put_nowait(conn)
 
     def is_all_free(self):
         """Indicates if all pool is free."""
         return self.pool_size == self.pool.qsize()
 
+    async def cleanup(self):
+        """Get all conn and close them, this method let this pool unusable."""
+        for _ in range(self.pool_size):
+            conn = self.pool.get()
+            conn.close()
+
 
 class SmartPool:
     """Pool which utilizes alive connections."""
@@ -48,10 +54,16 @@ class SmartPool:
         return self.pool.pop()
 
     def release(self, conn):
-        """Acquire connection."""
+        """Release connection."""
         self.pool.add(conn)
         self.sem.release()
 
     def is_all_free(self):
         """Indicates if all pool is free."""
         return self.pool_size == self.sem._value
+
+    async def cleanup(self):
+        """Get all conn and close them, this method let this pool unusable."""
+        for count in range(self.pool_size):
+            conn = await self.acquire()
+            conn.close()
